/**
 *     Copyright (C) 2009-2011  Jack A. Rider All rights reserved.
 * 
 *     This program is free software: you can redistribute it and/or modify
 *     it under the terms of the GNU General Public License as published by
 *     the Free Software Foundation, either version 3 of the License, or
 *     (at your option) any later version.
 * 
 *     This program is distributed in the hope that it will be useful,
 *     but WITHOUT ANY WARRANTY; without even the implied warranty of
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *     GNU General Public License for more details.
 */
 
 package org.xmlportletfactory.portal.goodclient;

import java.io.File;
import java.io.IOException;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.text.ParseException;
import java.text.DateFormat;
import java.text.SimpleDateFormat;
import java.util.ArrayList;
import java.util.Collections;
import java.util.Date;
import java.util.Enumeration;
import java.util.List;

import javax.portlet.ActionRequest;
import javax.portlet.ActionResponse;
import javax.portlet.Event;
import javax.portlet.EventRequest;
import javax.portlet.EventResponse;
import javax.portlet.PortletException;
import javax.portlet.PortletPreferences;
import javax.portlet.PortletRequestDispatcher;
import javax.portlet.PortletURL;
import javax.portlet.ProcessAction;
import javax.portlet.ProcessEvent;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;
import javax.xml.namespace.QName;

import org.apache.commons.fileupload.FileItem;
import org.apache.commons.fileupload.FileItemFactory;
import org.apache.commons.fileupload.FileUploadException;
import org.apache.commons.fileupload.disk.DiskFileItemFactory;
import org.apache.commons.fileupload.portlet.PortletFileUpload;

import org.xmlportletfactory.portal.goodclient.model.userTypes;
import org.xmlportletfactory.portal.goodclient.model.impl.userTypesImpl;
import org.xmlportletfactory.portal.goodclient.service.userTypesLocalServiceUtil;


import com.liferay.portal.kernel.cache.MultiVMPoolUtil;
import com.liferay.portal.kernel.dao.orm.Criterion;
import com.liferay.portal.kernel.dao.orm.DynamicQuery;
import com.liferay.portal.kernel.dao.orm.DynamicQueryFactoryUtil;
import com.liferay.portal.kernel.dao.orm.PropertyFactoryUtil;
import com.liferay.portal.kernel.dao.orm.RestrictionsFactoryUtil;
import com.liferay.portal.kernel.exception.PortalException;
import com.liferay.portal.kernel.exception.SystemException;
import com.liferay.portal.kernel.log.Log;
import com.liferay.portal.kernel.log.LogFactoryUtil;
import com.liferay.portal.kernel.servlet.SessionErrors;
import com.liferay.portal.kernel.servlet.SessionMessages;
import com.liferay.portal.kernel.util.OrderByComparator;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.Validator;
import com.liferay.portal.kernel.util.WebKeys;
import com.liferay.portal.model.User;
import com.liferay.portal.security.permission.PermissionChecker;
import com.liferay.portal.service.ServiceContext;
import com.liferay.portal.service.ServiceContextFactory;
import com.liferay.portal.service.UserLocalServiceUtil;
import com.liferay.portal.theme.ThemeDisplay;
import com.liferay.portlet.documentlibrary.model.DLFileEntry;
import com.liferay.portlet.documentlibrary.model.DLFolder;
import com.liferay.portlet.documentlibrary.service.DLFileEntryLocalServiceUtil;
import com.liferay.portlet.documentlibrary.service.DLFolderLocalServiceUtil;
import com.liferay.portlet.imagegallery.model.IGFolder;
import com.liferay.portlet.imagegallery.model.IGImage;
import com.liferay.portlet.imagegallery.service.IGFolderLocalServiceUtil;
import com.liferay.portlet.imagegallery.service.IGImageLocalServiceUtil;
import com.liferay.util.bridges.mvc.MVCPortlet;

/**
 * Portlet implementation class UserTypes
 */
public class UserTypesPortlet extends MVCPortlet {



	public void init() throws PortletException {

		// Edit Mode Pages
		editJSP = getInitParameter("edit-jsp");

		// Help Mode Pages
		helpJSP = getInitParameter("help-jsp");

		// View Mode Pages
		viewJSP = getInitParameter("view-jsp");

		// View Mode Edit userTypes
		edituserTypesJSP = getInitParameter("edit-userTypes-jsp");
	}

	protected void include(String path, RenderRequest renderRequest,
			RenderResponse renderResponse) throws IOException, PortletException {

		PortletRequestDispatcher portletRequestDispatcher = getPortletContext()
				.getRequestDispatcher(path);

		if (portletRequestDispatcher == null) {
			// do nothing
			// _log.error(path + " is not a valid include");
		} else {
			portletRequestDispatcher.include(renderRequest, renderResponse);
		}
	}

	public void doView(RenderRequest renderRequest,
			RenderResponse renderResponse) throws IOException, PortletException {

		String jsp = (String) renderRequest.getParameter("view");
		if (jsp == null || jsp.equals("")) {
			showViewDefault(renderRequest, renderResponse);
		} else if (jsp.equalsIgnoreCase("editUserTypes")) {
			try {
				showViewEditUserTypes(renderRequest, renderResponse);
			} catch (Exception ex) {
				_log.debug(ex);
				try {
					showViewDefault(renderRequest, renderResponse);
				} catch (Exception ex1) {
					_log.debug(ex1);
				}
			}
		}
	}

	public void doEdit(RenderRequest renderRequest,
			RenderResponse renderResponse) throws IOException, PortletException {

		showEditDefault(renderRequest, renderResponse);
	}

	public void doHelp(RenderRequest renderRequest,
			RenderResponse renderResponse) throws IOException, PortletException {

		include(helpJSP, renderRequest, renderResponse);
	}

	@SuppressWarnings("unchecked")
	public void showViewDefault(RenderRequest renderRequest,
			RenderResponse renderResponse) throws IOException, PortletException {

		ThemeDisplay themeDisplay = (ThemeDisplay) renderRequest
				.getAttribute(WebKeys.THEME_DISPLAY);

		long groupId = themeDisplay.getScopeGroupId();

		PermissionChecker permissionChecker = themeDisplay
				.getPermissionChecker();

		boolean hasAddPermission = permissionChecker.hasPermission(groupId,
				"org.xmlportletfactory.portal.goodclient.model", groupId, "ADD_USERTYPES");

		List<userTypes> tempResults = Collections.EMPTY_LIST;
		try {
			String orderByType = renderRequest.getParameter("orderByType");
			String orderByCol  = renderRequest.getParameter("orderByCol");
			OrderByComparator comparator = UserTypesComparator.getUserTypesOrderByComparator(orderByCol,orderByType);
			MultiVMPoolUtil.clear();

			String userTypesFilter = ParamUtil.getString(renderRequest, "userTypesFilter");
			if (userTypesFilter.equalsIgnoreCase("")) {
				tempResults = userTypesLocalServiceUtil.findAllInGroup(groupId, comparator);
			} else {
				DynamicQuery query = DynamicQueryFactoryUtil.forClass(userTypes.class)
				.add(
					PropertyFactoryUtil.forName("userTypeDescription").like("%"+ParamUtil.getString(renderRequest, "userTypesFilter")+"%")
				);
				tempResults = userTypesLocalServiceUtil.dynamicQuery(query, -1, -1, comparator);
			}
		
		} catch (Exception e) {
			_log.debug(e);
		}
		renderRequest.setAttribute("tempResults", tempResults);
		renderRequest.setAttribute("hasAddPermission", hasAddPermission);

		PortletURL addUserTypesURL = renderResponse.createActionURL();
		addUserTypesURL.setParameter("javax.portlet.action", "newUserTypes");
		renderRequest.setAttribute("addUserTypesURL", addUserTypesURL.toString());

		PortletURL userTypesFilterURL = renderResponse.createRenderURL();
		userTypesFilterURL.setParameter("javax.portlet.action", "doView");
		renderRequest.setAttribute("userTypesFilterURL", userTypesFilterURL.toString());

		include(viewJSP, renderRequest, renderResponse);
	}

	public void showViewEditUserTypes(RenderRequest renderRequest, RenderResponse renderResponse) throws Exception {

		SimpleDateFormat formatDia    = new SimpleDateFormat("dd");
		SimpleDateFormat formatMes    = new SimpleDateFormat("MM");
		SimpleDateFormat formatAno    = new SimpleDateFormat("yyyy");
		SimpleDateFormat formatHora   = new SimpleDateFormat("HH");
		SimpleDateFormat formatMinuto = new SimpleDateFormat("mm");

		PortletURL editUserTypesURL = renderResponse.createActionURL();
		String editType = (String) renderRequest.getParameter("editType");
		if (editType.equalsIgnoreCase("edit")) {
			editUserTypesURL.setParameter("javax.portlet.action", "updateUserTypes");
			long userTypeId = Long.parseLong(renderRequest.getParameter("userTypeId"));
			userTypes userTypes = userTypesLocalServiceUtil.getuserTypes(userTypeId);
			String userTypeDescription = userTypes.getUserTypeDescription()+"";
			renderRequest.setAttribute("userTypeDescription", userTypeDescription);
            renderRequest.setAttribute("userTypes", userTypes);
		} else {
			editUserTypesURL.setParameter("javax.portlet.action", "addUserTypes");
			userTypes errorUserTypes = (userTypes) renderRequest.getAttribute("errorUserTypes");
			if (errorUserTypes != null) {
				if (editType.equalsIgnoreCase("update")) {
					editUserTypesURL.setParameter("javax.portlet.action", "updateUserTypes");
                }
				renderRequest.setAttribute("userTypes", errorUserTypes);
			} else {
				userTypesImpl blankUserTypes = new userTypesImpl();
				blankUserTypes.setUserTypeId(0);
				blankUserTypes.setUserTypeDescription("");
				renderRequest.setAttribute("userTypes", blankUserTypes);
			}

		}

		ThemeDisplay themeDisplay = (ThemeDisplay) renderRequest.getAttribute(WebKeys.THEME_DISPLAY);


		renderRequest.setAttribute("editUserTypesURL", editUserTypesURL.toString());

		include(edituserTypesJSP, renderRequest, renderResponse);
	}

	private String dateToJsp(ActionRequest request, Date date) {
		PortletPreferences prefs = request.getPreferences();
		return dateToJsp(prefs, date);
	}
	private String dateToJsp(RenderRequest request, Date date) {
		PortletPreferences prefs = request.getPreferences();
		return dateToJsp(prefs, date);
	}
	private String dateToJsp(PortletPreferences prefs, Date date) {
		SimpleDateFormat format = new SimpleDateFormat(prefs.getValue("userTypes-date-format", "yyyy/MM/dd"));
		String stringDate = format.format(date);
		return stringDate;
	}
	private String dateTimeToJsp(Date date) {
		SimpleDateFormat format = new SimpleDateFormat("yyyy/MM/dd HH:mm");
		String stringDate = format.format(date);
		return stringDate;
	}

	public void showEditDefault(RenderRequest renderRequest,
			RenderResponse renderResponse) throws PortletException, IOException {

		include(editJSP, renderRequest, renderResponse);
	}

	/* Portlet Actions */

	@ProcessAction(name = "newUserTypes")
	public void newUserTypes(ActionRequest request, ActionResponse response) {
		response.setRenderParameter("view", "editUserTypes");
		response.setRenderParameter("editType", "add");
	}

	@ProcessAction(name = "addUserTypes")
	public void addUserTypes(ActionRequest request, ActionResponse response) throws Exception {
            ArrayList<String> errors = new ArrayList();
            userTypes userTypes = userTypesFromRequest(request);
            if (UserTypesValidator.validateUserTypes(userTypes, errors)) {
				userTypesLocalServiceUtil.adduserTypes(userTypes);
                MultiVMPoolUtil.clear();
                response.setRenderParameter("view", "");
                SessionMessages.add(request, "userTypes-added-successfully");
            } else {
                for (String error : errors) {
                        SessionErrors.add(request, error);
                }
                response.setRenderParameter("view", "editUserTypes");
                response.setRenderParameter("editType", "add");
                request.setAttribute("errorUserTypes", userTypes);
            }
	}

	@ProcessAction(name = "eventUserTypes")
	public void eventUserTypes(ActionRequest request, ActionResponse response)
			throws Exception {
		long key = ParamUtil.getLong(request, "resourcePrimKey");
		if (Validator.isNotNull(key)) {
		}
	}

	@ProcessAction(name = "editUserTypes")
	public void editUserTypes(ActionRequest request, ActionResponse response)
			throws Exception {
		long key = ParamUtil.getLong(request, "resourcePrimKey");
		if (Validator.isNotNull(key)) {
			response.setRenderParameter("userTypeId", Long.toString(key));
			response.setRenderParameter("view", "editUserTypes");
			response.setRenderParameter("editType", "edit");
		}
	}

	@ProcessAction(name = "deleteUserTypes")
	public void deleteUserTypes(ActionRequest request, ActionResponse response)throws Exception {
		long id = ParamUtil.getLong(request, "resourcePrimKey");
		if (Validator.isNotNull(id)) {
			userTypes userTypes = userTypesLocalServiceUtil.getuserTypes(id);
			userTypesLocalServiceUtil.deleteuserTypes(userTypes);
            MultiVMPoolUtil.clear();
			SessionMessages.add(request, "userTypes-deleted-successfully");
		} else {
			SessionErrors.add(request, "userTypes-error-deleting");
		}
	}

	@ProcessAction(name = "updateUserTypes")
	public void updateUserTypes(ActionRequest request, ActionResponse response) throws Exception {
            ArrayList<String> errors = new ArrayList();
            userTypes userTypes = userTypesFromRequest(request);
            if (UserTypesValidator.validateUserTypes(userTypes, errors)) {
                userTypesLocalServiceUtil.updateuserTypes(userTypes);
                MultiVMPoolUtil.clear();
                response.setRenderParameter("view", "");
                SessionMessages.add(request, "userTypes-updated-successfully");
            } else {
                for (String error : errors) {
                        SessionErrors.add(request, error);
                }
				response.setRenderParameter("userTypeId)",Long.toString(userTypes.getPrimaryKey()));
				response.setRenderParameter("view", "editUserTypes");
				response.setRenderParameter("editType", "update");
				request.setAttribute("errorUserTypes", userTypes);
            }
        }

	@ProcessAction(name = "setUserTypesPref")
	public void setUserTypesPref(ActionRequest request, ActionResponse response) throws Exception {

		String rowsPerPage = ParamUtil.getString(request, "userTypes-rows-per-page");
		String dateFormat = ParamUtil.getString(request, "userTypes-date-format");
		String datetimeFormat = ParamUtil.getString(request, "userTypes-datetime-format");

		ArrayList<String> errors = new ArrayList();
		if (UserTypesValidator.validateEditUserTypes(rowsPerPage, dateFormat, datetimeFormat, errors)) {
			response.setRenderParameter("userTypes-rows-per-page", "");
			response.setRenderParameter("userTypes-date-format", "");
			response.setRenderParameter("userTypes-datetime-format", "");

			PortletPreferences prefs = request.getPreferences();
			prefs.setValue("userTypes-rows-per-page", rowsPerPage);
			prefs.setValue("userTypes-date-format", dateFormat);
			prefs.setValue("userTypes-datetime-format", datetimeFormat);
			prefs.store();

			SessionMessages.add(request, "userTypes-prefs-success");
		}
	}

	private userTypes userTypesFromRequest(ActionRequest request) {
		ThemeDisplay themeDisplay = (ThemeDisplay) request.getAttribute(WebKeys.THEME_DISPLAY);
		userTypesImpl userTypes = new userTypesImpl();
        try {
            userTypes.setUserTypeId(ParamUtil.getLong(request, "userTypeId"));
        } catch (Exception nfe) {
		    //Controled en Validator
        }
		userTypes.setUserTypeDescription(ParamUtil.getString(request, "userTypeDescription"));
		try {
		    userTypes.setPrimaryKey(ParamUtil.getLong(request,"resourcePrimKey"));
		} catch (NumberFormatException nfe) {
			//Controled en Validator
        }
		userTypes.setCompanyId(themeDisplay.getCompanyId());
		userTypes.setGroupId(themeDisplay.getScopeGroupId());
		userTypes.setUserId(themeDisplay.getUserId());
		return userTypes;
	}

	protected String edituserTypesJSP;
	protected String editJSP;
	protected String helpJSP;
	protected String viewJSP;

	private static Log _log = LogFactoryUtil.getLog(UserTypesPortlet.class);

}
